@@ -47,7 +47,8 @@ typedef enum
   ELEMENT_INCLUDEDIR,
   ELEMENT_TYPE,
   ELEMENT_SELINUX,
-  ELEMENT_ASSOCIATE
+  ELEMENT_ASSOCIATE,
+  ELEMENT_STANDARD_SESSION_SERVICEDIRS
 } ElementType;
 
 typedef enum
@@ -161,6 +162,8 @@ element_type_to_name (ElementType type)
       return "fork";
     case ELEMENT_PIDFILE:
       return "pidfile";
+    case ELEMENT_STANDARD_SESSION_SERVICEDIRS:
+      return "standard_session_servicedirs";
     case ELEMENT_SERVICEDIR:
       return "servicedir";
     case ELEMENT_INCLUDEDIR:
@@ -286,6 +289,52 @@ merge_service_context_hash (DBusHashTable *dest,
   return FALSE;
 }
 
+static dbus_bool_t
+service_dirs_find_dir (DBusList **service_dirs,
+                       const char *dir)
+{
+  DBusList *link;
+
+  _dbus_assert (dir != NULL);
+
+  for (link = *service_dirs; link; link = _dbus_list_get_next_link(service_dirs, link))
+    {
+      const char *link_dir;
+      
+      link_dir = (const char *)link->data;
+      if (strcmp (dir, link_dir) == 0)
+        return TRUE;
+    }
+
+  return FALSE;
+}
+
+static dbus_bool_t
+service_dirs_append_unique_or_free (DBusList **service_dirs,
+                                    char *dir)
+{
+  if (!service_dirs_find_dir (service_dirs, dir))
+    return _dbus_list_append (service_dirs, dir);  
+
+  dbus_free (dir);
+  return TRUE;
+}
+
+static void 
+service_dirs_append_link_unique_or_free (DBusList **service_dirs,
+                                         DBusList *dir_link)
+{
+  if (!service_dirs_find_dir (service_dirs, dir_link->data))
+    {
+      _dbus_list_append_link (service_dirs, dir_link);
+    }
+  else
+    {
+      dbus_free (dir_link->data);
+      _dbus_list_free_link (dir_link);
+    }
+}
+
 static dbus_bool_t
 merge_included (BusConfigParser *parser,
                 BusConfigParser *included,
@@ -338,7 +387,7 @@ merge_included (BusConfigParser *parser,
     _dbus_list_append_link (&parser->mechanisms, link);
 
   while ((link = _dbus_list_pop_first_link (&included->service_dirs)))
-    _dbus_list_append_link (&parser->service_dirs, link);
+    service_dirs_append_link_unique_or_free (&parser->service_dirs, link);
 
   while ((link = _dbus_list_pop_first_link (&included->conf_dirs)))
     _dbus_list_append_link (&parser->conf_dirs, link);
@@ -752,6 +801,32 @@ start_busconfig_child (BusConfigParser   *parser,
           return FALSE;
         }
 
+      return TRUE;
+    }
+  else if (strcmp (element_name, "standard_session_servicedirs") == 0)
+    {
+      DBusList *link;
+      DBusList *dirs;
+      dirs = NULL;
+
+      if (!check_no_attributes (parser, "standard_session_servicedirs", attribute_names, attribute_values, error))
+        return FALSE;
+
+      if (push_element (parser, ELEMENT_STANDARD_SESSION_SERVICEDIRS) == NULL)
+        {
+          BUS_SET_OOM (error);
+          return FALSE;
+        }
+
+      if (!_dbus_get_standard_session_servicedirs (&dirs))
+        {
+          BUS_SET_OOM (error);
+          return FALSE;
+        }
+
+        while ((link = _dbus_list_pop_first_link (&dirs)))
+          service_dirs_append_link_unique_or_free (&parser->service_dirs, link);
+
       return TRUE;
     }
   else if (strcmp (element_name, "servicedir") == 0)
@@ -1881,6 +1956,7 @@ bus_config_parser_end_element (BusConfigParser   *parser,
     case ELEMENT_FORK:
     case ELEMENT_SELINUX:
     case ELEMENT_ASSOCIATE:
+    case ELEMENT_STANDARD_SESSION_SERVICEDIRS:
       break;
     }
 
@@ -2128,6 +2204,7 @@ bus_config_parser_content (BusConfigParser   *parser,
     case ELEMENT_ALLOW:
     case ELEMENT_DENY:
     case ELEMENT_FORK:
+    case ELEMENT_STANDARD_SESSION_SERVICEDIRS:    
     case ELEMENT_SELINUX:
     case ELEMENT_ASSOCIATE:
       if (all_whitespace (content))
@@ -2312,7 +2389,7 @@ bus_config_parser_content (BusConfigParser   *parser,
             goto nomem;
           }
 
-        if (!_dbus_list_append (&parser->service_dirs, s))
+        if (!service_dirs_append_unique_or_free (&parser->service_dirs, s))
           {
             _dbus_string_free (&full_path);
             dbus_free (s);
@@ -2986,6 +3063,91 @@ process_test_equiv_subdir (const DBusString *test_base_dir,
   return retval;
   
 }
+
+static const char *test_service_dir_matches[] = 
+        {
+         "/testusr/testlocal/testshare/dbus-1/services",
+         "/testusr/testshare/dbus-1/services",
+         DBUS_DATADIR"/dbus-1/services",
+         "/testhome/foo/.testlocal/testshare/dbus-1/services",         
+         NULL
+        };
+
+static dbus_bool_t
+test_default_session_servicedirs (void)
+{
+  DBusList *dirs;
+  DBusList *link;
+  int i;
+
+  dirs = NULL;
+
+  printf ("Testing retriving the default session service directories\n");
+  if (!_dbus_get_standard_session_servicedirs (&dirs))
+    _dbus_assert_not_reached ("couldn't get stardard dirs");
+
+  /* make sure our defaults end with share/dbus-1/service */
+  while ((link = _dbus_list_pop_first_link (&dirs)))
+    {
+      DBusString path;
+      
+      printf ("    default service dir: %s\n", (char *)link->data);
+      _dbus_string_init_const (&path, (char *)link->data);
+      if (!_dbus_string_ends_with_c_str (&path, "share/dbus-1/services"))
+        {
+          printf ("error with default session service directories\n");
+          return FALSE;
+        }
+ 
+      dbus_free (link->data);
+      _dbus_list_free_link (link);
+    }
+
+  if (!_dbus_setenv ("XDG_DATA_HOME", "/testhome/foo/.testlocal/testshare"))
+    _dbus_assert_not_reached ("couldn't setenv XDG_DATA_HOME");
+
+  if (!_dbus_setenv ("XDG_DATA_DIRS", ":/testusr/testlocal/testshare: :/testusr/testshare:"))
+    _dbus_assert_not_reached ("couldn't setenv XDG_DATA_DIRS");
+
+  if (!_dbus_get_standard_session_servicedirs (&dirs))
+    _dbus_assert_not_reached ("couldn't get stardard dirs");
+
+  /* make sure we read and parse the env variable correctly */
+  i = 0;
+  while ((link = _dbus_list_pop_first_link (&dirs)))
+    {
+      printf ("    test service dir: %s\n", (char *)link->data);
+      if (test_service_dir_matches[i] == NULL)
+        {
+          printf ("more directories parsed than in match set\n");
+          return FALSE;
+        }
+ 
+      if (strcmp (test_service_dir_matches[i], 
+                  (char *)link->data) != 0)
+        {
+          printf ("%s directory does not match %s in the match set\n", 
+                  (char *)link->data,
+                  test_service_dir_matches[i]);
+          return FALSE;
+        }
+
+      ++i;
+
+      dbus_free (link->data);
+      _dbus_list_free_link (link);
+    }
+  
+  if (test_service_dir_matches[i] != NULL)
+    {
+      printf ("extra data %s in the match set was not matched\n",
+              test_service_dir_matches[i]);
+
+      return FALSE;
+    }
+    
+  return TRUE;
+}
 			   
 dbus_bool_t
 bus_config_parser_test (const DBusString *test_data_dir)
@@ -2997,6 +3159,9 @@ bus_config_parser_test (const DBusString *test_data_dir)
       return TRUE;
     }
 
+  if (!test_default_session_servicedirs())
+    return FALSE;
+
   if (!process_test_valid_subdir (test_data_dir, "valid-config-files", VALID))
     return FALSE;
 
