@@ -436,16 +436,108 @@ bus_driver_handle_list_services (DBusConnection *connection,
       ++i;
     }
 
+  dbus_free_string_array (services);
+
   if (!dbus_message_iter_close_container (&iter, &sub))
+    {
+      dbus_message_unref (reply);
+      BUS_SET_OOM (error);
+      return FALSE;
+    }
+  
+  if (!bus_transaction_send_from_driver (transaction, connection, reply))
+    {
+      dbus_message_unref (reply);
+      BUS_SET_OOM (error);
+      return FALSE;
+    }
+  else
+    {
+      dbus_message_unref (reply);
+      return TRUE;
+    }
+}
+
+static dbus_bool_t
+bus_driver_handle_list_activatable_services (DBusConnection *connection,
+					     BusTransaction *transaction,
+					     DBusMessage    *message,
+					     DBusError      *error)
+{
+  DBusMessage *reply;
+  int len;
+  char **services;
+  BusActivation *activation;
+  int i;
+  DBusMessageIter iter;
+  DBusMessageIter sub;
+
+  _DBUS_ASSERT_ERROR_IS_CLEAR (error);
+
+  activation = bus_connection_get_activation (connection);
+
+  reply = dbus_message_new_method_return (message);
+  if (reply == NULL)
+    {
+      BUS_SET_OOM (error);
+      return FALSE;
+    }
+
+  if (!bus_activation_list_services (activation, &services, &len))
+    {
+      dbus_message_unref (reply);
+      BUS_SET_OOM (error);
+      return FALSE;
+    }
+
+  dbus_message_iter_init_append (reply, &iter);
+
+  if (!dbus_message_iter_open_container (&iter, DBUS_TYPE_ARRAY,
+					 DBUS_TYPE_STRING_AS_STRING,
+					 &sub))
     {
       dbus_free_string_array (services);
       dbus_message_unref (reply);
       BUS_SET_OOM (error);
       return FALSE;
     }
-  
+
+  {
+    /* Include the bus driver in the list */
+    const char *v_STRING = DBUS_SERVICE_DBUS;
+    if (!dbus_message_iter_append_basic (&sub, DBUS_TYPE_STRING,
+					 &v_STRING))
+      {
+	dbus_free_string_array (services);
+	dbus_message_unref (reply);
+	BUS_SET_OOM (error);
+	return FALSE;
+      }
+  }
+
+  i = 0;
+  while (i < len)
+    {
+      if (!dbus_message_iter_append_basic (&sub, DBUS_TYPE_STRING,
+					   &services[i]))
+	{
+	  dbus_free_string_array (services);
+	  dbus_message_unref (reply);
+	  BUS_SET_OOM (error);
+	  return FALSE;
+	}
+      ++i;
+    }
+
   dbus_free_string_array (services);
-  
+
+  if (!dbus_message_iter_close_container (&iter, &sub))
+    {
+      dbus_message_unref (reply);
+      BUS_SET_OOM (error);
+      return FALSE;
+    }
+
   if (!bus_transaction_send_from_driver (transaction, connection, reply))
     {
       dbus_message_unref (reply);
@@ -1328,6 +1420,10 @@ struct
     "",
     DBUS_TYPE_ARRAY_AS_STRING DBUS_TYPE_STRING_AS_STRING,
     bus_driver_handle_list_services },
+  { "ListActivatableNames",
+    "",
+    DBUS_TYPE_ARRAY_AS_STRING DBUS_TYPE_STRING_AS_STRING,
+    bus_driver_handle_list_activatable_services },
   { "AddMatch",
     DBUS_TYPE_STRING_AS_STRING,
     "",
@@ -1397,6 +1493,96 @@ write_args_for_direction (DBusString *xml,
   return FALSE;
 }
 
+dbus_bool_t
+bus_driver_generate_introspect_string (DBusString *xml)
+{
+  int i;
+
+  if (!_dbus_string_append (xml, DBUS_INTROSPECT_1_0_XML_DOCTYPE_DECL_NODE))
+    return FALSE;
+  if (!_dbus_string_append (xml, "<node>\n"))
+    return FALSE;
+  if (!_dbus_string_append_printf (xml, "  <interface name=\"%s\">\n", DBUS_INTERFACE_INTROSPECTABLE))
+    return FALSE;
+  if (!_dbus_string_append (xml, "    <method name=\"Introspect\">\n"))
+    return FALSE;
+  if (!_dbus_string_append_printf (xml, "      <arg name=\"data\" direction=\"out\" type=\"%s\"/>\n", DBUS_TYPE_STRING_AS_STRING))
+    return FALSE;
+  if (!_dbus_string_append (xml, "    </method>\n"))
+    return FALSE;
+  if (!_dbus_string_append (xml, "  </interface>\n"))
+    return FALSE;
+
+  if (!_dbus_string_append_printf (xml, "  <interface name=\"%s\">\n",
+                                   DBUS_INTERFACE_DBUS))
+    return FALSE;
+
+  i = 0;
+  while (i < _DBUS_N_ELEMENTS (message_handlers))
+    {
+	  
+      if (!_dbus_string_append_printf (xml, "    <method name=\"%s\">\n",
+                                       message_handlers[i].name))
+        return FALSE;
+
+      if (!write_args_for_direction (xml, message_handlers[i].in_args, TRUE))
+	return FALSE;
+
+      if (!write_args_for_direction (xml, message_handlers[i].out_args, FALSE))
+	return FALSE;
+
+      if (!_dbus_string_append (xml, "    </method>\n"))
+	return FALSE;
+      
+      ++i;
+    }
+
+  if (!_dbus_string_append_printf (xml, "    <signal name=\"NameOwnerChanged\">\n"))
+    return FALSE;
+  
+  if (!_dbus_string_append_printf (xml, "      <arg type=\"s\"/>\n"))
+    return FALSE;
+  
+  if (!_dbus_string_append_printf (xml, "      <arg type=\"s\"/>\n"))
+    return FALSE;
+  
+  if (!_dbus_string_append_printf (xml, "      <arg type=\"s\"/>\n"))
+    return FALSE;
+  
+  if (!_dbus_string_append_printf (xml, "    </signal>\n"))
+    return FALSE;
+
+
+
+  if (!_dbus_string_append_printf (xml, "    <signal name=\"NameLost\">\n"))
+    return FALSE;
+  
+  if (!_dbus_string_append_printf (xml, "      <arg type=\"s\"/>\n"))
+    return FALSE;
+  
+  if (!_dbus_string_append_printf (xml, "    </signal>\n"))
+    return FALSE;
+
+
+
+  if (!_dbus_string_append_printf (xml, "    <signal name=\"NameAcquired\">\n"))
+    return FALSE;
+  
+  if (!_dbus_string_append_printf (xml, "      <arg type=\"s\"/>\n"))
+    return FALSE;
+  
+  if (!_dbus_string_append_printf (xml, "    </signal>\n"))
+    return FALSE;
+
+  if (!_dbus_string_append (xml, "  </interface>\n"))
+    return FALSE;
+  
+  if (!_dbus_string_append (xml, "</node>\n"))
+    return FALSE;
+
+  return TRUE;
+}
+
 static dbus_bool_t
 bus_driver_handle_introspect (DBusConnection *connection,
                               BusTransaction *transaction,
@@ -1406,7 +1592,6 @@ bus_driver_handle_introspect (DBusConnection *connection,
   DBusString xml;
   DBusMessage *reply;
   const char *v_STRING;
-  int i;
 
   _dbus_verbose ("Introspect() on bus driver\n");
   
@@ -1427,95 +1612,15 @@ bus_driver_handle_introspect (DBusConnection *connection,
       return FALSE;
     }
 
-  if (!_dbus_string_append (&xml, DBUS_INTROSPECT_1_0_XML_DOCTYPE_DECL_NODE))
-    goto oom;
-  if (!_dbus_string_append (&xml, "<node>\n"))
-    goto oom;
-  if (!_dbus_string_append_printf (&xml, "  <interface name=\"%s\">\n", DBUS_INTERFACE_INTROSPECTABLE))
-    goto oom;
-  if (!_dbus_string_append (&xml, "    <method name=\"Introspect\">\n"))
-    goto oom;
-  if (!_dbus_string_append_printf (&xml, "      <arg name=\"data\" direction=\"out\" type=\"%s\"/>\n", DBUS_TYPE_STRING_AS_STRING))
-    goto oom;
-  if (!_dbus_string_append (&xml, "    </method>\n"))
-    goto oom;
-  if (!_dbus_string_append (&xml, "  </interface>\n"))
+  if (!bus_driver_generate_introspect_string (&xml))
     goto oom;
 
-  if (!_dbus_string_append_printf (&xml, "  <interface name=\"%s\">\n",
-                                   DBUS_INTERFACE_DBUS))
-    goto oom;
-
-  i = 0;
-  while (i < _DBUS_N_ELEMENTS (message_handlers))
-    {
-	  
-      if (!_dbus_string_append_printf (&xml, "    <method name=\"%s\">\n",
-                                       message_handlers[i].name))
-        goto oom;
-
-      if (!write_args_for_direction (&xml, message_handlers[i].in_args, TRUE))
-	goto oom;
-
-      if (!write_args_for_direction (&xml, message_handlers[i].out_args, FALSE))
-	goto oom;
-
-      if (!_dbus_string_append (&xml, "    </method>\n"))
-	goto oom;
-      
-      ++i;
-    }
-
-  if (!_dbus_string_append_printf (&xml, "    <signal name=\"NameOwnerChanged\">\n"))
-    goto oom;
-  
-  if (!_dbus_string_append_printf (&xml, "      <arg type=\"s\"/>\n"))
-    goto oom;
-  
-  if (!_dbus_string_append_printf (&xml, "      <arg type=\"s\"/>\n"))
-    goto oom;
-  
-  if (!_dbus_string_append_printf (&xml, "      <arg type=\"s\"/>\n"))
-    goto oom;
-  
-  if (!_dbus_string_append_printf (&xml, "    </signal>\n"))
-    goto oom;
-
-
-
-  if (!_dbus_string_append_printf (&xml, "    <signal name=\"NameLost\">\n"))
-    goto oom;
-  
-  if (!_dbus_string_append_printf (&xml, "      <arg type=\"s\"/>\n"))
-    goto oom;
-  
-  if (!_dbus_string_append_printf (&xml, "    </signal>\n"))
-    goto oom;
-
-
-
-  if (!_dbus_string_append_printf (&xml, "    <signal name=\"NameAcquired\">\n"))
-    goto oom;
-  
-  if (!_dbus_string_append_printf (&xml, "      <arg type=\"s\"/>\n"))
-    goto oom;
-  
-  if (!_dbus_string_append_printf (&xml, "    </signal>\n"))
-    goto oom;
-
-
-  
-  if (!_dbus_string_append (&xml, "  </interface>\n"))
-    goto oom;
-  
-  if (!_dbus_string_append (&xml, "</node>\n"))
-    goto oom;
+  v_STRING = _dbus_string_get_const_data (&xml);
 
   reply = dbus_message_new_method_return (message);
   if (reply == NULL)
     goto oom;
 
-  v_STRING = _dbus_string_get_const_data (&xml);
   if (! dbus_message_append_args (reply,
                                   DBUS_TYPE_STRING, &v_STRING,
                                   DBUS_TYPE_INVALID))
@@ -1638,7 +1743,7 @@ bus_driver_handle_message (DBusConnection *connection,
 void
 bus_driver_remove_connection (DBusConnection *connection)
 {
-  /* FIXME Does nothing for now, should unregister the connection
+  /* FIXME 1.0 Does nothing for now, should unregister the connection
    * with the bus driver.
    */
 }
