@@ -248,7 +248,9 @@ bus_expire_list_test (const DBusString *test_data_dir)
   long tv_sec_past, tv_usec_past;
   TestExpireItem *item;
   int next_interval;
-  
+  dbus_bool_t result = FALSE;
+
+
   loop = _dbus_loop_new ();
   _dbus_assert (loop != NULL);
 
@@ -276,6 +278,9 @@ bus_expire_list_test (const DBusString *test_data_dir)
 
   item = dbus_new0 (TestExpireItem, 1);
 
+  if (item == NULL)
+    goto oom;
+
   item->item.added_tv_sec = tv_sec;
   item->item.added_tv_usec = tv_usec;
   if (!_dbus_list_append (&list->items, item))
@@ -308,7 +313,10 @@ bus_expire_list_test (const DBusString *test_data_dir)
   bus_expire_list_free (list);
   _dbus_loop_unref (loop);
   
-  return TRUE;
+  result = TRUE;
+
+ oom:
+  return result;
 }
 
 #endif /* DBUS_BUILD_TESTS */
