@@ -36,7 +36,8 @@ typedef enum
   BUS_MATCH_MEMBER       = 1 << 2,
   BUS_MATCH_SENDER       = 1 << 3,
   BUS_MATCH_DESTINATION  = 1 << 4,
-  BUS_MATCH_PATH         = 1 << 5
+  BUS_MATCH_PATH         = 1 << 5,
+  BUS_MATCH_ARGS         = 1 << 6
 } BusMatchFlags;
 
 BusMatchRule* bus_match_rule_new   (DBusConnection *matches_go_to);
@@ -55,6 +56,9 @@ dbus_bool_t bus_match_rule_set_destination  (BusMatchRule *rule,
                                              const char   *destination);
 dbus_bool_t bus_match_rule_set_path         (BusMatchRule *rule,
                                              const char   *path);
+dbus_bool_t bus_match_rule_set_arg          (BusMatchRule *rule,
+                                             int           arg,
+                                             const char   *value);
 
 BusMatchRule* bus_match_rule_parse (DBusConnection   *matches_go_to,
                                     const DBusString *rule_text,
