@@ -676,7 +676,7 @@ _dbus_transport_handle_watch (DBusTransport           *transport,
 
   if (dbus_watch_get_fd (watch) < 0)
     {
-      _dbus_warn ("Tried to handle an invalidated watch; this watch should have been removed\n");
+      _dbus_warn_check_failed ("Tried to handle an invalidated watch; this watch should have been removed\n");
       return TRUE;
     }
   
